==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/java/MavenPackaging.java <==
package io.github.cdklabs.projen.java;

/**
 * (experimental) Configures a maven project to produce a .jar archive with sources and javadocs.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.824Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.java.MavenPackaging")
public class MavenPackaging extends io.github.cdklabs.projen.Component {

    protected MavenPackaging(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected MavenPackaging(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param pom This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public MavenPackaging(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.java.Pom pom, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.java.MavenPackagingOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(pom, "pom is required"), options });
    }

    /**
     * @param project This parameter is required.
     * @param pom This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public MavenPackaging(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.java.Pom pom) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(pom, "pom is required") });
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.java.MavenPackaging}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.java.MavenPackaging> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         * @param pom This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project, final io.github.cdklabs.projen.java.Pom pom) {
            return new Builder(project, pom);
        }

        private final io.github.cdklabs.projen.Project project;
        private final io.github.cdklabs.projen.java.Pom pom;
        private io.github.cdklabs.projen.java.MavenPackagingOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project, final io.github.cdklabs.projen.java.Pom pom) {
            this.project = project;
            this.pom = pom;
        }

        /**
         * (experimental) Where to place the package output?
         * <p>
         * Default: "dist/java"
         * <p>
         * @return {@code this}
         * @param distdir Where to place the package output?. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder distdir(final java.lang.String distdir) {
            this.options().distdir(distdir);
            return this;
        }

        /**
         * (experimental) Include javadocs jar in package.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param javadocs Include javadocs jar in package. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder javadocs(final java.lang.Boolean javadocs) {
            this.options().javadocs(javadocs);
            return this;
        }

        /**
         * (experimental) Exclude source files from docs.
         * <p>
         * Default: []
         * <p>
         * @return {@code this}
         * @param javadocsExclude Exclude source files from docs. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder javadocsExclude(final java.util.List<java.lang.String> javadocsExclude) {
            this.options().javadocsExclude(javadocsExclude);
            return this;
        }

        /**
         * (experimental) Include sources jar in package.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param sources Include sources jar in package. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder sources(final java.lang.Boolean sources) {
            this.options().sources(sources);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.java.MavenPackaging}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.java.MavenPackaging build() {
            return new io.github.cdklabs.projen.java.MavenPackaging(
                this.project,
                this.pom,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.java.MavenPackagingOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.java.MavenPackagingOptions.Builder();
            }
            return this.options;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/java/MavenPackaging.java <==
package io.github.cdklabs.projen.java;

/**
 * (experimental) Configures a maven project to produce a .jar archive with sources and javadocs.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.491Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.java.MavenPackaging")
public class MavenPackaging extends io.github.cdklabs.projen.Component {

    protected MavenPackaging(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected MavenPackaging(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param pom This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public MavenPackaging(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.java.Pom pom, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.java.MavenPackagingOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(pom, "pom is required"), options });
    }

    /**
     * @param project This parameter is required.
     * @param pom This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public MavenPackaging(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.java.Pom pom) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(pom, "pom is required") });
    }

    /**
     * (experimental) The directory containing the package output, relative to the project outdir.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getDistdir() {
        return software.amazon.jsii.Kernel.get(this, "distdir", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.java.MavenPackaging}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.java.MavenPackaging> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         * @param pom This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project, final io.github.cdklabs.projen.java.Pom pom) {
            return new Builder(project, pom);
        }

        private final io.github.cdklabs.projen.Project project;
        private final io.github.cdklabs.projen.java.Pom pom;
        private io.github.cdklabs.projen.java.MavenPackagingOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project, final io.github.cdklabs.projen.java.Pom pom) {
            this.project = project;
            this.pom = pom;
        }

        /**
         * (experimental) Where to place the package output?
         * <p>
         * Default: "dist/java"
         * <p>
         * @return {@code this}
         * @param distdir Where to place the package output?. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder distdir(final java.lang.String distdir) {
            this.options().distdir(distdir);
            return this;
        }

        /**
         * (experimental) Include javadocs jar in package.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param javadocs Include javadocs jar in package. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder javadocs(final java.lang.Boolean javadocs) {
            this.options().javadocs(javadocs);
            return this;
        }

        /**
         * (experimental) Exclude source files from docs.
         * <p>
         * Default: []
         * <p>
         * @return {@code this}
         * @param javadocsExclude Exclude source files from docs. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder javadocsExclude(final java.util.List<java.lang.String> javadocsExclude) {
            this.options().javadocsExclude(javadocsExclude);
            return this;
        }

        /**
         * (experimental) Include sources jar in package.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param sources Include sources jar in package. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder sources(final java.lang.Boolean sources) {
            this.options().sources(sources);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.java.MavenPackaging}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.java.MavenPackaging build() {
            return new io.github.cdklabs.projen.java.MavenPackaging(
                this.project,
                this.pom,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.java.MavenPackagingOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.java.MavenPackagingOptions.Builder();
            }
            return this.options;
        }
    }
}
